/**
 * Copyright (c) 2015-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the LICENSE file in
 * the root directory of this source tree.
 *
 * @flow
 * @format
 */

import jscs from './jscodeshift';

/**
 * This module helps support a hack to easily introduce new lines into the AST.
 */
const NewLine = {
  literal: '$$newline$$',
  replace(input: string): string {
    /**
     * This regex functions by matching:
     *
     *   - contiguous new lines
     *   - non new line characters
     *   - the string "$$newline$$" and surrounding characters
     *   - non new line characters
     *   - contiguous new lines
     *
     * This way it only removes extra new lines around the explicit new lines
     * we have added in the file. It does not remove arbitrary extra new lines.
     */
    return input.replace(/(\n*[^\n]*\$\$newline\$\$[^\n]*\n*){1,}/g, '\n\n');
  },
  get statement() {
    return jscs.expressionStatement(jscs.literal(NewLine.literal));
  },
};

export default NewLine;
